#!/usr/bin/env bash
set -e
APP="$(dirname "$0")"
eos="$APP/EoS/eos"

BASE="$(basename "$0" .sh)"
eval set -- $(getopt -o R:o: -l output: -n "$BASE" -- "$@")

RP='0/140'
OBN="$BASE"

while true; do
    case "$1" in
	-R)
	    RP="$2"
	    shift 2
	    ;;
	-o|--output)
	    OBN="$2"
	    shift 2
	    ;;
	--)
	    shift
	    break
	    ;;
	*)
	    echo "${BASE}: Error processing arguments" >&2
	    exit 1
	    ;;
    esac
done

JR=(-JX15c -R"$RP/2/20")

# awk 'BEGIN{i=0} !/^#/{p[i]=$1/1e9;T[i]=$2; if(i>=4){print(p[2],((T[0]-T[4])/12+(T[3]-T[1])*2/3)/(p[2]-p[1])); p[0]=p[1];p[1]=p[2];p[2]=p[3];p[3]=p[4]; T[0]=T[1];T[1]=T[2];T[2]=T[3];T[3]=T[4]}else{++i}}' "$APP/pyrolite_adiabat1600K.txt" \
# | psxy "${JR[@]}" -Wthick,red,.. -K >"$OBN.eps"

$eos prop -db=SLB11 ALL -o='p,T,alpha,V,Cp' <"$APP/pyrolite_adiabat1600K_x.txt" \
| awk '!/^#/{print($1/1e9,$3*$4*$2/$5*1e9)}' \
| psxy "${JR[@]}" -Wthick,red -K >"$OBN.eps"

$eos prop -db=SLB11 ALL -o='p,T,alpha,V,Cp' <"$APP/bulkoc_adiabat1600K_x.txt" \
| awk '!/^#/{print($1/1e9,$3*$4*$2/$5*1e9)}' \
| psxy "${JR[@]}" -Wthick,blue -O -K >>"$OBN.eps"

$eos prop -db=SLB11 ALL -o='p,T,alpha,V,Cp' <"$APP/dplman_adiabat1600K_x.txt" \
| awk '!/^#/{print($1/1e9,$3*$4*$2/$5*1e9)}' \
| psxy "${JR[@]}" -Wthick,black -O -K >>"$OBN.eps"

"$APP/prem2p.py" -z --dp "$APP/Katsura2010-Fig3.csv" \
| psxy "${JR[@]}" -Wthick,darkgreen,-- -O -K >>"$OBN.eps"

psbasemap "${JR[@]}" -B'a10b5:P/GPa:/a2b1:dT/dP / K GPa@+-1@+:' -O -K >>"$OBN.eps"

pslegend ${JR[@]} -Dx17.5/11.25/5/7.5/ML -O <<EOF >>"$OBN.eps"
#S 0 - 0.5 - thick,red,.. 0.5 EoS / SLB11 (numerical gradient)
S 0 - 0.5 - thick,red 0.5 Pyrolite
S 0 - 0.5 - thick,blue 0.5 Bulk Oceanic Crust
S 0 - 0.5 - thick,black 0.5 Depleted Mantle
S 0 - 0.5 - thick,darkgreen,-- 0.5 Katsura [2010]
EOF

epspdf "$OBN.eps"
