#!/usr/bin/env bash
set -e
APP="$(dirname "$0")"

BASE="$(basename "$0" .sh)"
eval set -- $(getopt -o R:o: -l output: -n "$BASE" -- "$@")

JR=(-JX15c -R0/140/1400/3200)
TS=($(seq 1400 200 1800))
OUT="${BASE}.eps"

while true; do
    case "$1" in
	-R)
	    JR[1]="-R$2"
	    shift 2
	    ;;
	-o|--output)
	    OUT="$2"
	    shift 2
	    ;;
	--)
	    shift
	    break
	    ;;
	*)
	    echo "${BASE}: Error processing arguments" >&2
	    exit 1
	    ;;
    esac
done

psxy ${JR[@]} -T -K >"$OUT"

for T in ${TS[@]}; do
    awk '!/^#/{print($1/1e9,$2)}' "$APP/pyrolite_adiabat${T}K.txt" \
    | psxy ${JR[@]} -Wthick,red -O -K >>"$OUT"

    awk '!/^#/{print($1/1e9,$2)}' "$APP/bulkoc_adiabat${T}K.txt" \
    | psxy ${JR[@]} -Wthick,blue -O -K >>"$OUT"

    awk '!/^#/{print($1/1e9,$2)}' "$APP/dplman_adiabat${T}K.txt" \
    | psxy ${JR[@]} -Wthick,black -O -K >>"$OUT"
done

"$APP/prem2p.py" -d "$APP/Brown1981-Fig2.csv" \
| psxy ${JR[@]} -Wthick,darkgreen -O -K >>"$OUT"

"$APP/prem2p.py" -d "$APP/Katsura2010-Fig4.csv" \
| psxy ${JR[@]} -Wthick,darkgreen,-.. -O -K >>"$OUT"

"$APP/prem2p.py" -r "$APP/Stacey2008-geotherm.txt" \
| psxy ${JR[@]} -Wthick,darkgreen,-- -O -K >>"$OUT"

psbasemap ${JR[@]} -B'a10f5:p/GPa:/a500f100:T/K:' -O -K >>"$OUT"

pslegend ${JR[@]} -Dx17.5/11.25/5/7.5/ML -O <<EOF >>"$OUT"
S 0 - 0.8 - thick,red 0.5 Pyrolite
S 0 - 0.8 - thick,blue 0.5 Bulk Oceanic Crust
S 0 - 0.8 - thick,black 0.5 Depleted Mantle
S 0 - 0.8 - thick,darkgreen 0.5 Adiabat from Brown and Shankland [1981]
S 0 - 0.8 - thick,darkgreen,-.. 0.5 Adiabat from Katsura et al. [2010]
S 0 - 0.8 - thick,darkgreen,-- 0.5 Geotherm from Stacey and Davis [2008]
EOF

epspdf "$OUT"
