#!/usr/bin/env bash
set -e
APP="$(dirname "$0")"
OUT="$(basename "$0" .sh).eps"
eos="$APP/EoS/eos"

JR=(-JX15c -R0/1/-1/60)
#PT=(-P=1e5Pa -T=1700K)
PT=(-P=1e5Pa -T=1773K)

H0=$($eos prop ${PT[@]} -x=1,0 -o=G,T,S -db=SLB11 plg | awk '!/^#/{print($1+$2*$3)}')
H1=$($eos prop ${PT[@]} -x=0,1 -o=G,T,S -db=SLB11 plg | awk '!/^#/{print($1+$2*$3)}')

awk 'BEGIN{for(i=0;i<=100;++i){x=i/100;print(1-x, x)}}' \
| $eos prop ${PT[@]} -o=x,G,T,S -db=SLB11 plg \
| awk "BEGIN{H0=$H0;H1=$H1}"' !/^#/{f=$2;H=$3+$4*$5;print(f,(H-(1-f)*H0-f*H1)/1e3)}' \
| psxy ${JR[@]} -Wthick,blue -K >"$OUT"

H0r=$($eos prop ${PT[0]} -T=298K -x=1,0 -o=G,T,S -db=SLB11 plg | awk '!/^#/{print($1+$2*$3)}')
H1r=$($eos prop ${PT[0]} -T=298K -x=0,1 -o=G,T,S -db=SLB11 plg | awk '!/^#/{print($1+$2*$3)}')

# Data by Navrotsky et al. 1989
awk "BEGIN{H0=($H0)-($H0r);H1=($H1)-($H1r)}"' !/^#/{f=$1;H=$2*1e3;dH=$3;print(f,(H-(1-f)*H0-f*H1)/1e3,dH)}' <<EOF \
| psxy ${JR[@]} -Sc8p -Ey -O -K >>"$OUT"
0.875 530.9 4.8
0.750 532.2 10.3
0.625 534.9 15.0
0.500 545.6 15.3
0.350 546.3 13.6
EOF

# Data by Carpenter et al. 1985
# awk '{x=(100-$1)/100;print(x,$2)}' <<EOF | psxy ${JR[@]} -Sc8p -O -K >>"$OUT"
# 100 17.40
# 98  17.28
# 98  17.05
# 97  17.03
# 96  17.81
# 96  16.98
# 86  17.53
# 86  16.13
# 78  17.21
# 78  15.46
# 72  16.66
# 72  14.77
# 71  17.12
# 71  14.54
# 71  14.70
# 71  14.73
# 68  16.01
# 68  15.33
# 67  17.36
# 67  15.57
# 60  17.77
# 60  14.97
# 60  17.15
# 60  15.42
# 49  17.76
# 49  15.62
# 40  17.25
# 40  15.85
# 35  18.09
# 35  16.53
# 27  17.59
# 27  15.95
# 20  18.61
# 20  16.31
# 1   20.26
# 1   17.18
# EOF

# awk '{x=(100-$1)/100;print(x,$2)}' <<EOF | psxy ${JR[@]} -Sc8p -O -K >>"$OUT"
# 100 NaN
# 98  0.23
# 96  0.83
# 89  NaN
# 86  1.40
# 78  1.75
# 72  1.89
# 71  2.58
# 71  2.42
# 68  0.68
# 67  1.79
# 60  2.80
# 60  1.73
# 49  2.14
# 40  1.40
# 35  1.56
# 27  1.64
# 20  2.30
# 1   3.08
# EOF

psbasemap ${JR[@]} -B'a0.1f0.05:x[ab]:/a2f1:H/kJ mol@+-1@+:WSEn' -O >>"$OUT"
epspdf "$OUT"
