#!/usr/bin/env bash
set -e
APP="$(dirname "$0")"
OUT="$(basename "$0" .sh).eps"
eos="$APP/EoS/eos"

TMPDIR="$(mktemp --tmpdir -d an-ab.XXXXXXXXXX)"
trap "rm -rf '$TMPDIR'" EXIT

S0="$TMPDIR/S0"
BUF="$TMPDIR/buf"

JR=(-JX15c -R0/1.01/-1/12)
PT=(-P=1e5Pa -T=1700K)

awk 'BEGIN{for(x=0;x<1.0;x+=0.01) print(1-x, x)}' \
| $eos prop ${PT[@]} -db=SLB11 -o=x,S an ab \
| awk '!/^#/{print($2,$3)}' >"$S0"

awk 'BEGIN{for(x=0;x<1.0;x+=0.01) print(1-x, x)}' \
| $eos prop ${PT[@]} -db=SLB11 -o=x,S plg \
| awk '!/^#/{print($2,$3)}' >"$BUF"

join "$S0" "$BUF" \
| awk '{print($1,$3-$2)}' \
| psxy ${JR[@]} -Wthick,blue -K >"$OUT"

awk 'BEGIN{for(x=0;x<1.0;x+=0.01) print(1-x, 0, 0, x)}' \
| $eos prop ${PT[@]} -db=SLB11 -o=x,S plg plg \
| awk '!/^#/{print($4,$5)}' >"$BUF"

join "$S0" "$BUF" \
| awk '{print($1,$3-$2)}' \
| psxy ${JR[@]} -Wthick,gray,-- -O -K >>"$OUT"

awk 'BEGIN{for(x=0;x<1.0;x+=0.01) print(1-x, x)}' \
| $eos prop ${PT[@]} -db="$APP/an-ab-alt.xml" -o=x,S plg \
| awk '!/^#/{print($2,$3)}' >"$BUF"

join "$S0" "$BUF" \
| awk '{print($1,$3-$2)}' \
| psxy ${JR[@]} -Wthick,blue,-- -O -K >>"$OUT"

psbasemap ${JR[@]} -B'a0.1f0.05:x[ab]:/a2f1:S/J mol@+-1@+ K@+-1@+:WSEn' -O >>"$OUT"
epspdf "$OUT"
