#!/usr/bin/env bash
set -e
APP="$(dirname "$0")"
OUT="$(basename "$0" .sh).eps"
eos="$APP/EoS/eos"

TMPDIR="$(mktemp --tmpdir -d di-cats.XXXXXXXXXX)"
trap "rm -rf '$TMPDIR'" EXIT

S0="$TMPDIR/S0"
BUF="$TMPDIR/buf"

JR=(-JX15c -R0/1/0/1.7)
PT=(-P=1e5Pa -T=1700K)

# Ionic disordered

awk 'BEGIN{for(i=0;i<=100;++i){x=i/100; print(1-x, x)}}' \
| $eos prop ${PT[@]} -db=SLB11 -o=x,S di cats \
| awk '!/^#/{print($2,$3)}' >"$S0"

awk 'BEGIN{for(i=0;i<=100;++i){x=i/100; print(1-x, 0, 0, x, 0)}}' \
| $eos prop ${PT[@]} -db=SLB11 -o=x,S cpx \
| awk '!/^#/{print($4,$6)}' >"$BUF"

join "$S0" "$BUF" \
| awk '{print($1,($3-$2)/10)}' \
| psxy ${JR[@]} -Wthick,blue -K >"$OUT"

# Baseline

awk 'BEGIN{for(i=0;i<=100;++i){x=i/100; print(1-x, 0, 0, 0, 0, 0, 0, 0, x, 0)}}' \
| $eos prop ${PT[@]} -db=SLB11 -o=x,S cpx cpx \
| awk '!/^#/{print($9,$11)}' >"$BUF"

join "$S0" "$BUF" \
| awk '{print($1,($3-$2)/10)}' \
| psxy ${JR[@]} -Wthick,gray,-- -O -K >>"$OUT"

# Ionic, Al avoidance

awk 'BEGIN{for(i=0;i<=100;++i){x=i/100; print(1-x, 0, 0, x, 0)}}' \
| $eos prop ${PT[@]} -db="$APP/di-cats-avoidance.xml" -o=x,S cpx \
| awk '!/^#/{print($4,$6)}' >"$BUF"

join "$S0" "$BUF" \
| awk '{print($1,($3-$2)/10)}' \
| psxy ${JR[@]} -Wthick,darkgreen -O -K >>"$OUT"

# Ionic, partial avoidance

awk 'BEGIN{for(i=0;i<=100;++i){x=i/100; print(1-x, 0, 0, x, 0)}}' \
| $eos prop ${PT[@]} -db="$APP/di-cats-partial.xml" -o=x,S cpx \
| awk '!/^#/{print($4,$6)}' >"$BUF"

join "$S0" "$BUF" \
| awk '{print($1,($3-$2)/10)}' \
| psxy ${JR[@]} -Wthick,magenta -O -K >>"$OUT"

# Charge-coupled, disordered

awk 'BEGIN{for(i=0;i<=100;++i){x=i/100; print(1-x, 0, 0, x, 0)}}' \
| $eos prop ${PT[@]} -db="$APP/di-cats-cc.xml" -o=x,S cpx \
| awk '!/^#/{print($4,$6)}' >"$BUF"

join "$S0" "$BUF" \
| awk '{print($1,($3-$2)/10)}' \
| psxy ${JR[@]} -Wthick,blue,-- -O -K >>"$OUT"

# Charge-coupled, Al avoidance

awk 'BEGIN{for(i=0;i<=100;++i){x=i/100; print(1-x, 0, 0, x, 0)}}' \
| $eos prop ${PT[@]} -db="$APP/di-cats-cc-avoidance.xml" -o=x,S cpx \
| awk '!/^#/{print($4,$6)}' >"$BUF"

join "$S0" "$BUF" \
| awk '{print($1,($3-$2)/10)}' \
| psxy ${JR[@]} -Wthick,darkgreen,-- -O -K >>"$OUT"

# Charge-coupled, partial avoidance

awk 'BEGIN{for(i=0;i<=100;++i){x=i/100; print(1-x, 0, 0, x, 0)}}' \
| $eos prop ${PT[@]} -db="$APP/di-cats-cc-partial.xml" -o=x,S cpx \
| awk '!/^#/{print($4,$6)}' >"$BUF"

join "$S0" "$BUF" \
| awk '{print($1,($3-$2)/10)}' \
| psxy ${JR[@]} -Wthick,magenta,-- -O -K >>"$OUT"

# psxy ${JR[@]} -S8p -Wthin,black -O -K >>"$OUT" <<EOF
# # Vinograd 2001
# 0.00379264 0.10101 c
# 0.250867 9.59596 c
# 0.500476 12.5253 c
# 0.749419 11.9192 c
# 0.997637 7.47475 c
# # Warren et al. 2001
# 0.00379264 0.10101 d
# 0.246998 9.09091 d
# 0.499981 9.89899 d
# 0.500381 12.0202 d
# 0.997637 7.47475 d
# # Cohen 1986
# 0.398494 12.0202 s
# 0.602478 13.1313 s
# 0.802306 12.2222 s
# 1.00 8.08081 s
# EOF

awk '{print($1,($2*8.3144621)/10)}' "$APP/Cohen1986-Fig3c.csv" \
| psxy ${JR[@]} -Wthin,black,-.- -O -K >>"$OUT"

awk '{print($1,$2/10)}' "$APP/Vinograd2001-Fig18.csv" \
| psxy ${JR[@]} -Wthin,brown,-.- -O -K >>"$OUT"

# awk '{x=$1; print(1-x, x)}' "$APP/Gasparik1984-Fig5.csv" \
# | $eos prop ${PT[@]} -db=SLB11 -o=x,S di cats \
# | awk '!/^#/{print($2,$3)}' >"$S0"

# awk '{x=$1; print(1-x, 0, 0, 0, 0, 0, 0, 0, x, 0)}' "$APP/Gasparik1984-Fig5.csv" \
# | $eos prop ${PT[@]} -db=SLB11 -o=x,S cpx cpx \
# | awk '!/^#/{print($9,$11)}' >"$BUF"

# join "$S0" "$BUF" \
# | join - "$APP/Gasparik1984-Fig5.csv" \
# | awk '{print($1,($3-$2+$4)/10)}' \
# | psxy ${JR[@]} -Wthin,darkgreen -O -K >>"$OUT"

psbasemap ${JR[@]} -B'a0.1f0.05:x[cats]:/a0.2f0.1:S@-cf@-/J mol@+-1@+ atom@+-1@+ K@+-1@+:WSEn' -O >>"$OUT"
epspdf "$OUT"
