#!/usr/bin/env bash
set -e
APP="$(dirname "$0")"
OUT="$(basename "$0" .sh).eps"
eos="$APP/EoS/eos"

JR=(-JX15c -R0/1/0/1400)
PT=(-P=1e5Pa -T=1700K)

H0=$($eos prop ${PT[@]} -x=1,0,0,0,0 -o=G,T,S -db=SLB11 cpx | awk '!/^#/{print($1+$2*$3)}')
H1=$($eos prop ${PT[@]} -x=0,0,1,0,0 -o=G,T,S -db=SLB11 cpx | awk '!/^#/{print($1+$2*$3)}')

awk 'BEGIN{for(i=0;i<=100;++i){x=i/100;print(x, 0, 1-x, 0, 0)}}' \
| $eos prop ${PT[@]} -o=x,G,T,S -db=SLB11 cpx \
| awk "BEGIN{H0=$H0;H1=$H1}"' !/^#/{f=$1;H=$6+$7*$8;print(f,(H-f*H0-(1-f)*H1)/10)}' \
| psxy ${JR[@]} -Wthick,blue -K >"$OUT"

H0=$($eos prop ${PT[@]} -x=1,0,0,0,0 -o=G,T,S -db="$APP/di-en-alt.xml" cpx | awk '!/^#/{print($1+$2*$3)}')
H1=$($eos prop ${PT[@]} -x=0,0,1,0,0 -o=G,T,S -db="$APP/di-en-alt.xml" cpx | awk '!/^#/{print($1+$2*$3)}')

awk 'BEGIN{for(i=0;i<=100;++i){x=i/100;print(x, 0, 1-x, 0, 0)}}' \
| $eos prop ${PT[@]} -o=x,G,T,S -db="$APP/di-en-alt.xml" cpx \
| awk "BEGIN{H0=$H0;H1=$H1}"' !/^#/{f=$1;H=$6+$7*$8;print(f,(H-f*H0-(1-f)*H1)/10)}' \
| psxy ${JR[@]} -Wthick,blue,-- -O -K >>"$OUT"

# Newton et al. 1979
awk 'BEGIN{u=4186.8/10;H0=20.38;H1=17.20} {f=$1/100;print(f,(f*H0+(1-f)*H1-$2)*u,$3*u)}' <<EOF \
| psxy ${JR[@]} -Sc8p -Wthin,black -Ey -O -K >>"$OUT"
100 20.38 0.21
90  19.22 0.37
90  19.52 0.25
80  18.20 0.15
80  18.59 0.17
70  17.06 0.29
70  17.30 0.35
60  16.23 0.17
50  15.76 0.23
40  15.44 0.12
30  15.17 0.28
22  15.51 0.35
0   17.20 0.21
EOF

psbasemap ${JR[@]} -B'a0.1f0.05:x[di]:/a200f50:H@-ex@-/J mol@+-1@+ atom@+-1@+:WSEn' -O >>"$OUT"
epspdf "$OUT"
