#!/usr/bin/env bash
set -e
APP="$(dirname "$0")"
OUT="$(basename "$0" .sh).eps"
eos="$APP/EoS/eos"

TMPDIR="$(mktemp --tmpdir -d di-en.XXXXXXXXXX)"
trap "rm -rf '$TMPDIR'" EXIT

S0="$TMPDIR/S0"
BUF="$TMPDIR/buf"

JR=(-JX15c -R0/1/0/1.6)
PT=(-P=1e5Pa -T=1700K)

awk 'BEGIN{for(i=0;i<=100;++i){x=i/100;print(x, 1-x)}}' \
| $eos prop ${PT[@]} -db=SLB11 -o=x,S di cen \
| awk '!/^#/{print($1,$3)}' >"$S0"

awk 'BEGIN{for(i=0;i<=100;++i){x=i/100;print(x, 0, 1-x, 0, 0)}}' \
| $eos prop ${PT[@]} -db=SLB11 -o=x,S cpx \
| awk '!/^#/{print($1,$6)}' >"$BUF"

join "$S0" "$BUF" \
| awk '{print($1,($3-$2)/10)}' \
| psxy ${JR[@]} -Wthick,blue -K >"$OUT"

awk 'BEGIN{for(i=0;i<=100;++i){x=i/100;print(x, 0, 0, 0, 0, 0, 0, 1-x, 0, 0)}}' \
| $eos prop ${PT[@]} -db=SLB11 -o=x,S cpx cpx \
| awk '!/^#/{print($1,$11)}' >"$BUF"

join "$S0" "$BUF" \
| awk '{print($1,($3-$2)/10)}' \
| psxy ${JR[@]} -Wthick,gray,-- -O -K >>"$OUT"

psbasemap ${JR[@]} -B'a0.1f0.05:x[di]:/a0.2f0.1:S@-cf@-/J mol@+-1@+ atom@+-1@+ K@+-1@+:WSEn' -O >>"$OUT"
epspdf "$OUT"
