#!/usr/bin/env bash
set -e
APP="$(dirname "$0")"
OUT="$(basename "$0" .sh).eps"
eos="$APP/EoS/eos"

NAME="$(basename "$0")"
SLB11=1
HHP13=0
EXPERIMENTAL=0

eval set -- "$(getopt -o e --long experimental,slb11,hhp13 -n "$NAME" -- "$@")"
while true; do
    case "$1" in
	-e|--experimental)
	    EXPERIMENTAL=$(expr $EXPERIMENTAL = 0 || true)
	    shift
	    ;;
	--slb11)
	    SLB11=$(expr $SLB11 = 0 || true)
	    shift
	    ;;
	--hhp13)
	    HHP13=$(expr $HHP13 = 0 || true)
	    shift
	    ;;
	--)
	    shift
	    break
	    ;;
	*)
	    echo "$NAME: error parsing command line" >&2
	    exit 1
	    ;;
    esac
done

JR=(-JX15c -R300/1400/10/60)
psxy ${JR[@]} -T -K >"$OUT"

if [ $SLB11 -ne 0 ]; then
    $eos prop -db=SLB11 fa -P=1e5Pa -T=300K -toT=1400K -nT=71 -o=T,S \
    | awk '!/^#/{print($1,$2/7)}' \
    | psxy ${JR[@]} -Wthick,darkgreen -O -K >>"$OUT"

    $eos prop -db=SLB11 fewa -P=1e5Pa -T=300K -toT=1400K -nT=71 -o=T,S \
    | awk '!/^#/{print($1,$2/7)}' \
    | psxy ${JR[@]} -Wthick,red -O -K >>"$OUT"

    $eos prop -db=SLB11 feri -P=1e5Pa -T=300K -toT=1400K -nT=71 -o=T,S \
    | awk '!/^#/{print($1,$2/7)}' \
    | psxy ${JR[@]} -Wthick,blue -O -K >>"$OUT"
fi

if [ $HHP13 -ne 0 ]; then
    $eos prop -db=HHP13 fa -P=1e5Pa -T=300K -toT=1400K -nT=71 -o=T,S \
    | awk '!/^#/{print($1,$2/7)}' \
    | psxy ${JR[@]} -Wthick,green,-- -O -K >>"$OUT"

    $eos prop -db=HHP13 fwd -P=1e5Pa -T=300K -toT=1400K -nT=71 -o=T,S \
    | awk '!/^#/{print($1,$2/7)}' \
    | psxy ${JR[@]} -Wthick,orange,-- -O -K >>"$OUT"

    $eos prop -db=HHP13 frw -P=1e5Pa -T=300K -toT=1400K -nT=71 -o=T,S \
    | awk '!/^#/{print($1,$2/7)}' \
    | psxy ${JR[@]} -Wthick,cyan,-- -O -K >>"$OUT"
fi

psbasemap ${JR[@]} -B'a300f100+300:T/K:/a10f5:S/J mol@+-1@+ atom@+-1@+ K@+-1@+:' -O -K >>"$OUT"

pslegend ${JR[@]} -Dx17/7.5/5/15/ML -O -K <<EOF >>"$OUT"
S 0 - 0.5 - thick 0.5 SLB11
S 0 - 0.5 - thick,darkgreen 0.5 fa
S 0 - 0.5 - thick,red 0.5 Fe-wa
S 0 - 0.5 - thick,blue 0.5 Fe-ri
EOF
pslegend ${JR[@]} -Dx22/7.5/5/15/ML -O <<EOF >>"$OUT"
S 0 - 0.5 - thick,-- 0.5 HHP13
S 0 - 0.5 - thick,green,-- 0.5 fa
S 0 - 0.5 - thick,orange,-- 0.5 Fe-wa
S 0 - 0.5 - thick,cyan,-- 0.5 Fe-ri
EOF

epspdf "$OUT"
