#!/usr/bin/env bash
set -e
APP="$(dirname "$0")"
BASE="$(basename "$0" .sh)"
eos="$APP/EoS/eos"

TMPDIR="$(mktemp --tmpdir -d femg-abc-pyrolite.XXXXXXXXXX)"
trap "rm -rf '$TMPDIR'" EXIT

BUF="$TMPDIR/buf"
GRD="$TMPDIR/rgb"

RI=(-R0/130/300/4300 -I0.1/50)
#JR=(-JX15/15c -R0.05/0.15/0/25)
JR=(-JX15/15c -R0.0/0.2/0/25)

OUT="${BASE}_abc.eps"
PSF="${BASE}_abc.txt"

# if [ "$1" = "-calc" ]; then
#     awk '!/^#/{print($1,$2)}' "$APP/pyrolite_adiabat1500K.txt" \
#     | mpirun -np $(nproc) $eos opti \
# 	-bulk='Mg2SiO4' -tobulk='(Mg0.8Fe0.2)2SiO4' -nbulk=21 -o='p,xbulk,x' \
# 	-db=SLB11 ol wa ri >"$PSF"
# fi

awk '!/^#/{all=($3+$4+$5+$6+$7+$8);if(all>0)print($2*0.2,$1/1e9,($5+$6)/all*256)}' "$PSF" \
| xyz2grd -R0.0/0.2/0/25 -I0.01/0.1 -G"$GRD.r"

awk '!/^#/{all=($3+$4+$5+$6+$7+$8);if(all>0)print($2*0.2,$1/1e9,($3+$4)/all*256)}' "$PSF" \
| xyz2grd -R0.0/0.2/0/25 -I0.01/0.1 -G"$GRD.g"

awk '!/^#/{all=($3+$4+$5+$6+$7+$8);if(all>0)print($2*0.2,$1/1e9,($7+$8)/all*256)}' "$PSF" \
| xyz2grd -R0.0/0.2/0/25 -I0.01/0.1 -G"$GRD.b"

grdimage ${JR[@]} "$GRD".{r,g,b} -t66 -K >"$OUT"

PSF='pyrolite.txt'

function trace {
    awk '!/^#/{print($1/1e9,$2)}' "$APP/pyrolite_adiabat1500K.txt" \
    | grdtrack -G"$BUF" \
    | awk '!/^#/{print($3,$1)}' \
    | psxy ${JR[@]} "$@" -O -K >>"$OUT"
}

function mark {
    psxy ${JR[@]} -Wthin,black -O -K <<EOF >>"$OUT"
0.1101437258 0
0.1101437258 25
EOF
}

mark

awk '!/^#/{fe=$9;all=$8+$9;if(all>0)print($1/1e9,$2,fe/all)}' "$PSF" \
| xyz2grd ${RI[@]} -G"$BUF"

trace -Wthick,darkgreen

awk '!/^#/{fe=$11;all=$10+$11;if(all>0)print($1/1e9,$2,fe/all)}' "$PSF" \
| xyz2grd ${RI[@]} -G"$BUF"

trace -Wthick,red

awk '!/^#/{fe=$13;all=$12+$13;if(all>0)print($1/1e9,$2,fe/all)}' "$PSF" \
| xyz2grd ${RI[@]} -G"$BUF"

trace -Wthick,blue

# Data from Frost 2003
psxy ${JR[@]} -O -K <<EOF >>"$OUT"
> -Wthin,black,..
0.00 20.00
0.15 17.43
0.20 16.57
> -Wthin,black,..
0.00 20.00
0.15 15.20
0.20 13.60
> -Wthin,black,..
0.00 14.57
0.15 13.52
0.20 13.17
> -Wthin,black,..
0.00 14.57
0.15 13.03
0.20 12.52
> -Wthick,blue,--
0.11 24.70
0.11 18.20
0.15 17.43
> -Wthick,red,--
0.08 17.43
0.10 16.73
0.10 13.87
0.14 13.59
> -Wthick,darkgreen,--
0.07 13.80
0.09 13.66
0.09 8.00
EOF

# Data from Frost 2003b
psxy ${JR[@]} -Sh8p -O -K <<EOF >>"$OUT"
> -Gdarkgreen -W-
0.218 9.5
> -Gred -W-
0.121 18
0.144 14
> -Gblue -W-
0.202 18
0.147 15
0.178 18
0.175 18
0.169 18
EOF

# Data from Ishii et al. 2011
awk 'BEGIN{MgO=0.0403044;FeO=0.0718464} {print(($2/FeO)/($2/FeO+$3/MgO),$1)}' <<EOF | psxy ${JR[@]} -Sc8p -Gblue -O -K >>"$OUT"
22.9 9.91 49.30
22.9 7.67 47.81
23.3 9.03 48.52
24.1 6.39 35.03
24.1 5.50 35.60
25.3 6.45 35.39
EOF

# Data from Kato et al. 2014
awk 'BEGIN{MgO=0.0403044;FeO=0.0718464} {print(($2/FeO)/($2/FeO+$3/MgO),$1)}' <<EOF | psxy ${JR[@]} -St8p -Gblue -O -K >>"$OUT"
22.5 8.6 52.3
23.0 8.0 49.4
23.5 9.0 47.9
EOF

# Data from Wood 2000
awk '/^>/{print} !/^>/{print(1-$1,$2)}' <<EOF | psxy ${JR[@]} -Si8p -O -K >>"$OUT"
> -Gred -W-
0.913 19.0
> -Gblue -W-
0.888 19.0
0.894 22.5
0.900 22.5
0.900 23.0
EOF

pstext ${JR[@]} -F+f -O -K <<EOF >>"$OUT"
0.1 6 darkgreen ol
0.105 15.5 red wa
0.115 20.5 blue ri
EOF

psbasemap ${JR[@]} -B'a0.02f0.01:Fe/(Mg+Fe):/a2f1:P/GPa:' -O >>"$OUT"
epspdf "$OUT"

OUT="${BASE}_pxp.eps"
PSF="${BASE}_pxp.txt"

# if [ "$1" = "-calc" ]; then
#     awk '!/^#/{print($1,$2)}' "$APP/pyrolite_adiabat1500K.txt" \
#     | mpirun -np $(nproc) $eos opti \
# 	-bulk='(MgO)1.4472(CaO)0.0759(Al2O3)0.0573(Na2O)0.0028(SiO2)' \
# 	-tobulk='(MgO)1.2472(FeO)0.2000(CaO)0.0759(Al2O3)0.0573(Na2O)0.0028(SiO2)' \
# 	-nbulk=21 -relax -o='p,xbulk,x' \
# 	-db=SLB11 opx hpcpx gt ak pv >"$PSF"
# fi

awk '!/^#/{p=0;t=0;for(i=3;i<=19;++i){t+=$(i);if(3<=i&&i<=6){p+=$(i)}}if(t>0)print($2*0.2,$1/1e9,p/t)}' "$PSF" \
| xyz2grd -R0.0/0.2/0/25 -I0.01/0.1 -G"$GRD.opx"

awk '!/^#/{p=0;t=0;for(i=3;i<=19;++i){t+=$(i);if(7<=i&&i<=8){p+=$(i)}}if(t>0)print($2*0.2,$1/1e9,p/t)}' "$PSF" \
| xyz2grd -R0.0/0.2/0/25 -I0.01/0.1 -G"$GRD.hpcpx"

awk '!/^#/{p=0;t=0;for(i=3;i<=19;++i){t+=$(i);if(9<=i&&i<=13){p+=$(i)}}if(t>0)print($2*0.2,$1/1e9,p/t)}' "$PSF" \
| xyz2grd -R0.0/0.2/0/25 -I0.01/0.1 -G"$GRD.gt"

awk '!/^#/{p=0;t=0;for(i=3;i<=19;++i){t+=$(i);if(14<=i&&i<=16){p+=$(i)}}if(t>0)print($2*0.2,$1/1e9,p/t)}' "$PSF" \
| xyz2grd -R0.0/0.2/0/25 -I0.01/0.1 -G"$GRD.ak"

awk '!/^#/{p=0;t=0;for(i=3;i<=19;++i){t+=$(i);if(17<=i&&i<=19){p+=$(i)}}if(t>0)print($2*0.2,$1/1e9,p/t)}' "$PSF" \
| xyz2grd -R0.0/0.2/0/25 -I0.01/0.1 -G"$GRD.pv"

grdmath 1 "$GRD.pv" SUB "$GRD.opx" "$GRD.ak" ADD MUL 128 MUL = "$GRD.r"
grdmath 1 "$GRD.pv" SUB "$GRD.hpcpx" MUL 256 MUL = "$GRD.g"
grdmath 1 "$GRD.pv" SUB "$GRD.gt" "$GRD.ak" ADD MUL 128 MUL = "$GRD.b"

grdimage ${JR[@]} "$GRD".{r,g,b} -t66 -K >"$OUT"

PSF='pyrolite.txt'

mark

awk '!/^#/{fe=2*$15;mg=2*$14+$16+$17;all=fe+mg;if(all>0)print($1/1e9,$2,fe/all)}' "$PSF" \
| xyz2grd ${RI[@]} -G"$BUF"

trace -Wthick,red

awk '!/^#/{fe=2*$24;mg=2*$23;all=fe+mg;if(all>0)print($1/1e9,$2,fe/all)}' "$PSF" \
| xyz2grd ${RI[@]} -G"$BUF"

trace -Wthick,darkgreen

awk '!/^#/{fe=3*$30;mg=3*$29+4*$32;all=fe+mg;if(all>0)print($1/1e9,$2,fe/all)}' "$PSF" \
| xyz2grd ${RI[@]} -G"$BUF"

trace -Wthick,blue

awk '!/^#/{fe=$27;mg=$26;all=fe+mg;if(all>0)print($1/1e9,$2,fe/all)}' "$PSF" \
| xyz2grd ${RI[@]} -G"$BUF"

trace -Wthick,cyan

awk '!/^#/{fe=$39;mg=$38;all=fe+mg;if(all>0)print($1/1e9,$2,fe/all)}' "$PSF" \
| xyz2grd ${RI[@]} -G"$BUF"

trace -Wthick,black

# Data from Frost 2003
psxy ${JR[@]} -O -K <<EOF >>"$OUT"
> -Wthick,blue,--
0.0842697 20
0.0833256 18.9955
0.0824043 18.4951
0.0823954 18.2972
0.0823845 18.0545
0.084629 17.9948
0.0888941 17.894
0.0927101 17.8006
0.0967504 17.696
0.100566 17.5915
0.104382 17.5019
0.107973 17.3973
0.110217 17.3376
0.110651 16.9866
0.109438 14.9925
> -Wthick,blue,--
0.10982 14.4935
0.109263 13.9991
0.109687 13.8967
0.109223 13.8209
0.118589 13.7766
0.124832 13.7455
0.134642 13.6968
0.144453 13.648
0.144446 13.6168
0.144419 13.4965
0.143861 12.9976
0.142856 12.4943
EOF

# Data from Frost 2003b
psxy ${JR[@]} -Sh8p -Gblue -O -K <<EOF >>"$OUT"
0.144 18
0.149 15
0.135 18
0.124 18
0.293 9.5
0.148 14
EOF

# Data from Irifune & Ringwood 1987
awk 'BEGIN{MgO=0.0403044;FeO=0.0718464} {print(($2/FeO)/($2/FeO+$3/MgO),$1)}' <<EOF | psxy ${JR[@]} -Sd8p -Gred -O -K >>"$OUT"
5.0 2.64 35.90
8.0 3.90 36.13
EOF
awk 'BEGIN{MgO=0.0403044;FeO=0.0718464} {print(($2/FeO)/($2/FeO+$3/MgO),$1)}' <<EOF | psxy ${JR[@]} -Sd8p -Gblue -O -K >>"$OUT"
8.0 6.06 20.47
EOF

# Data from Ishii et al. 2011
awk 'BEGIN{MgO=0.0403044;FeO=0.0718464} {print(($2/FeO)/($2/FeO+$3/MgO),$1)}' <<EOF | psxy ${JR[@]} -Sc8p -Gblue -O -K >>"$OUT"
22.9 6.73 26.06
22.9 4.41 28.34
22.9 3.46 29.12
23.3 3.36 26.23
23.8 4.50 28.98
23.8 4.51 31.55
24.1 3.48 27.57
24.1 3.13 26.92
EOF
awk 'BEGIN{MgO=0.0403044;FeO=0.0718464} {print(($2/FeO)/($2/FeO+$3/MgO),$1)}' <<EOF | psxy ${JR[@]} -Sc8p -Gcyan -O -K >>"$OUT"
22.9 3.11 38.53
EOF

# Data from Kato et al. 2014
awk 'BEGIN{MgO=0.0403044;FeO=0.0718464} {print(($2/FeO)/($2/FeO+$3/MgO),$1)}' <<EOF | psxy ${JR[@]} -St8p -Gblack -O -K >>"$OUT"
22.5 5.5 38.6
23.0 6.0 35.5
23.5 4.5 36.0
24.0 3.8 39.5
25.0 4.1 36.6
EOF

# Data from Wood 2000
awk '/^>/{print} !/^>/{print(1-$1,$2)}' <<EOF | psxy ${JR[@]} -Si8p -O -K >>"$OUT"
> -Gblue -W-
0.876 19.0
0.911 22.5
0.923 22.5
0.915 23.5
0.903 23.0
> -Gblack -W-
0.919 22.5
0.961 22.5
0.908 23.5
0.912 23.0
0.907 26.0
EOF

pstext ${JR[@]} -F+f -O -K <<EOF >>"$OUT"
0.10  4 red opx
0.08 11 darkgreen hpcpx
0.16 12 blue gt
0.04 22 cyan ak
0.06 24 black br
EOF

psbasemap ${JR[@]} -B'a0.02f0.01:Fe/(Mg+Fe):/a2f1:P/GPa:' -O >>"$OUT"
epspdf "$OUT"
