#!/usr/bin/env bash
set -e
APP="$(dirname "$0")"
eos="$APP/EoS/eos"

BASE="$(basename "$0" .sh)"
OUT="${BASE}.eps"
TEMP="$(mktemp -d -t "${BASE}.XXXXXXXXXX")"
trap "rm -rf '$TEMP'" EXIT

JR=(-JX15c -R0/55/300/3100)
psxy ${JR[@]} -T -K >"$OUT"

function trace {
  awk '!/^#/{print($1/1e9,$2,and(rshift($3,9),1))}' "$1" \
    | xyz2grd -G"$TEMP/ak.grd" ${JR[1]} -I0.1/50
  grdcontour ${JR[@]} -C1 -W"$2" "$TEMP/ak.grd" -O -K >>"$OUT"
}

awk '!/^#/{print($1/1e9,$2)}' pyrolite_adiabat1600K.txt \
| psxy ${JR[@]} -Wthick,black,-- -O -K >>"$OUT"

trace pyrolite.txt thick,red
trace dplman.txt thick,brown
trace bulkoc.txt thick,blue

#trace ms.txt thick,blue
#trace fms.txt thick,cyan
#trace cfms.txt thick,green
#trace fmas.txt thick,orange
#trace cfmas.txt thick,magenta

psbasemap ${JR[@]} -B'a10f5:P/GPa:/a500+300f100:T/K:' -O -K >>"$OUT"

pslegend ${JR[@]} -Dx17.5/11.25/5/7.5/ML -O <<EOF >>"$OUT"
S 0 - 0.5 - thick,red 0.5 Pyrolite
S 0 - 0.5 - thick,brown 0.5 Depleted Mantle
S 0 - 0.5 - thick,blue 0.5 Bulk Oceanic Crust
#S 0 - 0.5 - thick,blue 0.5 MS
#S 0 - 0.5 - thick,cyan 0.5 FMS
#S 0 - 0.5 - thick,green 0.5 CFMS
#S 0 - 0.5 - thick,orange 0.5 FMAS
#S 0 - 0.5 - thick,magenta 0.5 CFMAS
#S 0 - 0.5 - thick,red 0.5 NCFMAS
EOF

epspdf "$OUT"
