#!/usr/bin/env bash
set -e
APP="$(dirname "$0")"
eos="$APP/EoS/eos"

PH0="${1:-fo}"
PH1="${2:-$PH0}"
CPT="${3:-$APP/gibbs-energy-fo.cpt}"
OUT="gibbs-energy-${PH0}.eps"

TMPDIR="$(mktemp --tmpdir -d gibbs-energy.XXXXXXXXXX)"
trap "rm -rf '$TMPDIR'" EXIT

JR=(-JX15c -R0/26/300/3000)

G0=$($eos prop -db=SLB11 "$PH0" -P=1e5Pa -T=300K -o=G,atoms | awk '!/^#/{print($1/$2/1e3)}')
G1=$($eos prop -db=HHP13 "$PH1" -P=1e5Pa -T=300K -o=G,atoms | awk '!/^#/{print($1/$2/1e3)}')

$eos prop -db=SLB11 "$PH0" -P=1e5Pa -toP=26e9Pa -nP=261 -T=300K -toT=3000K -nT=55 -o=p,T,G,atoms \
| awk '!(/^#/||/Exception/){print($1/1e9,$2,$3/$4/1e3)}' \
| xyz2grd -V ${JR[1]} -I0.1/50 -G"$TMPDIR/${PH0}_slb11.grd"

$eos prop -db=HHP13 "$PH1" -P=1e5Pa -toP=26e9Pa -nP=261 -T=300K -toT=3000K -nT=55 -o=p,T,G,atoms \
| awk '!(/^#/||/Exception/){print($1/1e9,$2,$3/$4/1e3)}' \
| xyz2grd -V ${JR[1]} -I0.1/50 -G"$TMPDIR/${PH1}_hhp13.grd"

grdmath "$TMPDIR/${PH0}_slb11.grd" "$TMPDIR/${PH1}_hhp13.grd" SUB "$G0" "$G1" SUB SUB = "$TMPDIR/${PH0}_delta.grd"
grdinfo "$TMPDIR/${PH0}_delta.grd"

# CPT="$TMPDIR/${PH0}_delta.cpt"
# grd2cpt "$TMPDIR/${PH0}_delta.grd" -Cpolar >"$CPT"

grdimage ${JR[@]} "$TMPDIR/${PH0}_delta.grd" -C"$CPT" -K >"$OUT"
grdcontour ${JR[@]} "$TMPDIR/${PH0}_delta.grd" -C"$CPT" -A+f'16p,Helvetica,black' -O -K >>"$OUT"

psscale -D18/7.5/15/1 -B':@~D@~G/kJ K@+-1@+ mol@+-1@+ atom@+-1@+:' -C"$CPT" -O -K >>"$OUT"
psbasemap ${JR[@]} -B"a5f1:P/GPa:/a500f100:T/K:" -O >>"$OUT"
epstopdf "$OUT"
