#!/usr/bin/env bash
set -e
APP="$(dirname "$0")"
OUT="$(basename "$0" .sh).eps"
eos="$APP/EoS/eos"

NAME="$(basename "$0")"
SLB11=1
HHP13=0
ROH95=0
POLYMORPHS=1
EXPERIMENTAL=0

eval set -- "$(getopt -o pe --long polymorphs,experimental,slb11,hhp13,roh95 -n "$NAME" -- "$@")"
while true; do
    case "$1" in
	-p|--polymorphs)
	    POLYMORPHS=$(expr $POLYMORPHS = 0 || true)
	    shift
	    ;;
	-e|--experimental)
	    EXPERIMENTAL=$(expr $EXPERIMENTAL = 0 || true)
	    shift
	    ;;
	--slb11)
	    SLB11=$(expr $SLB11 = 0 || true)
	    shift
	    ;;
	--hhp13)
	    HHP13=$(expr $HHP13 = 0 || true)
	    shift
	    ;;
	--roh95)
	    ROH95=$(expr $ROH95 = 0 || true)
	    shift
	    ;;
	--)
	    shift
	    break
	    ;;
	*)
	    echo "$NAME: error parsing command line" >&2
	    exit 1
	    ;;
    esac
done

JR=(-JX15c -R300/1400/16/30)
psxy ${JR[@]} -T -K >"$OUT"

if [ $SLB11 -ne 0 ]; then
    $eos prop -db=SLB11 fa -P=1e5Pa -T=300K -toT=1400K -nT=36 -o=T,Cp \
    | awk '!/^#/{print($1,$2/7)}' \
    | psxy ${JR[@]} -Wthick,darkgreen -O -K >>"$OUT"

    if [ $POLYMORPHS -ne 0 ]; then
	$eos prop -db=SLB11 feri -P=1e5Pa -T=300K -toT=1400K -nT=36 -o=T,Cp \
	| awk '!/^#/{print($1,$2/7)}' \
	| psxy ${JR[@]} -Wthick,blue -O -K >>"$OUT"

	$eos prop -db=SLB11 fewa -P=1e5Pa -T=300K -toT=1400K -nT=36 -o=T,Cp \
	| awk '!/^#/{print($1,$2/7)}' \
	| psxy ${JR[@]} -Wthick,red -O -K >>"$OUT"
    fi
fi

if [ $HHP13 -ne 0 ]; then
    if [ $POLYMORPHS -ne 0 ]; then
	$eos prop -db=HHP13 fwd -P=1e5Pa -T=300K -toT=1400K -nT=36 -o=T,Cp \
	| awk '!/^#/{print($1,$2/7)}' \
	| psxy ${JR[@]} -Wthick,orange -O -K >>"$OUT"
    fi

    $eos prop -db=HHP13 fa -P=1e5Pa -T=300K -toT=1400K -nT=36 -o=T,Cp \
    | awk '!/^#/{print($1,$2/7)}' \
    | psxy ${JR[@]} -Wthick,green,-- -O -K >>"$OUT"

    if [ $POLYMORPHS -ne 0 ]; then
	$eos prop -db=HHP13 frw -P=1e5Pa -T=300K -toT=1400K -nT=36 -o=T,Cp \
	| awk '!/^#/{print($1,$2/7)}' \
	| psxy ${JR[@]} -Wthick,cyan,-- -O -K >>"$OUT"
    fi
fi

if [ $ROH95 -ne 0 ]; then
    # Robie & Hemingway 1995
    awk 'BEGIN{for(T=300;T<1800;T+=10){print(T,(1.7602e2+(-8.808e-3+2.471e-5*T)*T-3.889e6/T/T)/7)}}' \
    | psxy ${JR[@]} -Wthick,blue,-- -O -K >>"$OUT"
fi

if [ $EXPERIMENTAL -ne 0 ]; then
# Robie et al. 1982
awk '{print($1,$2/7)}' <<EOF \
| psxy ${JR[@]} -Sc8p -Wthin,black -O -K >>"$OUT"
300.04 132.3
305.35 133.7
311.65 135.1
316.91 136.3
322.20 137.1
327.59 138.5
333.36 139.9
339.56 141.1
345.70 142.4
351.80 143.5
356.14 144.2
362.20 145.4
368.31 146.6
375.27 147.7
381.47 148.8
EOF

# Watanabe 1982
awk '!/^[#>]/{print($1,$2*4.1868/7)} /^>/{print}' <<EOF | psxy ${JR[@]} -Sd8p -Wthin,black -O -K >>"$OUT"
350.523	34.6479
360.239	35.2703
370.765	35.5987
380.528	35.7411
390.664	36.0694
400.423	36.2427
410.565	36.5091
420.321	36.7134
430.47	36.9023
440.229	37.0912
450.367	37.3885
460.512	37.6239
470.656	37.8593
480.807	38.0328
490.516	38.7171
500.273	38.9214
510.821	39.033
520.571	39.2993
530.739	39.3024
540.883	39.5378
550.643	39.7112
560.804	39.7762
570.568	39.9031
581.104	40.1387
590.877	40.1727
601.029	40.3306
611.196	40.3338
621.344	40.5382
631.493	40.7272
641.241	41.0244
651.002	41.1822
661.54	41.3868
671.301	41.5447
681.454	41.7026
691.988	41.9536
701.347	42.2198
EOF
fi

psbasemap ${JR[@]} -B'a300f100+300:T/K:/a2f1:C@-p@-/J mol@+-1@+ atom@+-1@+ K@+-1@+:' -O -K >>"$OUT"

if [ $POLYMORPHS -ne 0 ]; then
    if [ $SLB11 -ne 0 ]; then
pslegend ${JR[@]} -Dx17/7.5/5/15/ML -O -K <<EOF >>"$OUT"
S 0 - 0.5 - thick 0.5 SLB11
S 0 - 0.5 - thick,darkgreen 0.5 fa
S 0 - 0.5 - thick,red 0.5 Fe-wa
S 0 - 0.5 - thick,blue 0.5 Fe-ri
EOF
    fi
    if [ $HHP13 -ne 0 ]; then
pslegend ${JR[@]} -Dx22/7.5/5/15/ML -O -K <<EOF >>"$OUT"
S 0 - 0.5 - thick,-- 0.5 HHP13
S 0 - 0.5 - thick,green,-- 0.5 fa
S 0 - 0.5 - thick,orange,-- 0.5 Fe-wa
S 0 - 0.5 - thick,cyan,-- 0.5 Fe-ri
EOF
    fi
    if [ $ROH95 -ne 0 ]; then
pslegend ${JR[@]} -Dx27/7.5/5/15/ML -O -K <<EOF >>"$OUT"
S 0 - 0.5 - thick,blue,-- 0.5 ROH95
EOF
    fi
else
pslegend ${JR[@]} -Dx17/7.5/5/15/ML -O -K <<EOF >>"$OUT"
S 0 - 0.5 - thick,darkgreen 0.5 SLB11
S 0 - 0.5 - thick,green,-- 0.5 HHP13
S 0 - 0.5 - thick,blue,-- 0.5 ROH95
EOF
fi

if [ $EXPERIMENTAL -ne 0 ]; then
pslegend ${JR[@]} -Dx22/2.5/5/5/ML -O -K <<EOF >>"$OUT"
S 0 c 8p - thin,black 0.5 Robie et al. 1982
S 0 d 8p - thin,black 0.5 Watanabe 1982
EOF
fi

psxy ${JR[@]} -T -O >>"$OUT"

epspdf "$OUT"
