#!/usr/bin/env bash
set -e
APP="$(dirname "$0")"
eos="$APP/EoS/eos"

BASE="$(basename "$0" .sh)"
eval set -- $(getopt -o R:o: -l output:,calc -n "$BASE" -- "$@")

RP='0/140'
OBN="$BASE"
CALC=0

while true; do
    case "$1" in
	-R)
	    RP="$2"
	    shift 2
	    ;;
	-o|--output)
	    OBN="$2"
	    shift 2
	    ;;
	--calc)
	    CALC=1
	    shift
	    ;;
	--)
	    shift
	    break
	    ;;
	*)
	    echo "${BASE}: Error processing arguments" >&2
	    exit 1
	    ;;
    esac
done

BUF="$(mktemp --tmpdir -d pbd-elastic.XXXXXXXXXX)"
trap "rm -rf '$BUF'" EXIT

J='-JX15c'
DB='-db=SLB11'

case "$RP" in
    0/55)
	RR="-R${RP}/2.9/4.9"
	RVP="-R${RP}/6/12"
	RVS="-R${RP}/3/7"
	;;
    85/140)
	RR="-R${RP}/5.0/5.8"
	RVP="-R${RP}/12.75/14"
	RVS="-R${RP}/6.75/7.5"
	;;
    *)
	RR="-R${RP}/2/6"
	RVP="-R${RP}/3/15"
	RVS="-R${RP}/3/15"
	;;
esac

# # PREM
# awk '!/^#/{print($8,$4/1e3)}' "$APP/prem.txt" \
# | psxy $J $RR -Wthick,darkgreen,-- -K >"${OBN}-rho.eps"
#
# awk '!/^#/{print($8,$2/1e3)}' "$APP/prem.txt" \
# | psxy $J $RVP -Wthick,darkgreen,-- -K >"${OBN}-vp.eps"
# awk '!/^#/{print($8,$3/1e3)}' "$APP/prem.txt" \
# | psxy $J $RVS -Wthick,darkgreen,-- -K >"${OBN}-vs.eps"

# AK135
awk '!/^#/{print($1,$4)}' "$APP/ak135.txt" \
| psxy $J $RR -Wthick,darkgreen,-- -K >"${OBN}-rho.eps"

awk '!/^#/{print($1,$2)}' "$APP/ak135.txt" \
| psxy $J $RVP -Wthick,darkgreen,-- -K >"${OBN}-vp.eps"
awk '!/^#/{print($1,$3)}' "$APP/ak135.txt" \
| psxy $J $RVS -Wthick,darkgreen,-- -K >"${OBN}-vs.eps"

RI=(-R0/140/300/4300 -I0.1/50)

for PA in pyrolite bulkoc dplman; do
    if [ $CALC -ne 0 ]; then
	cut -f1,2,4- "$PA.txt" \
	| mpirun -np $(nproc) $eos prop -o='p,T,rho,vp&vs' $DB ALL >"${PA}_elastic.txt"
    fi

    awk '!/^#/{print($1/1e9,$2,$3/1e3)}' "${PA}_elastic.txt" \
    | xyz2grd ${RI[@]} -G"$BUF/${PA}_r.grd"
    awk '!/^#/{print($1/1e9,$2,$4/1e3)}' "${PA}_elastic.txt" \
    | xyz2grd ${RI[@]} -G"$BUF/${PA}_vp.grd"
    awk '!/^#/{print($1/1e9,$2,$5/1e3)}' "${PA}_elastic.txt" \
    | xyz2grd ${RI[@]} -G"$BUF/${PA}_vs.grd"
done

function plotit {
    PA="$1"
    C1="$2"
    C2="$3"

    awk '!/^#/{print($1/1e9,$2)}' "${PA}_adiabat1600K.txt" >"$BUF/pT.txt"

    grdtrack "$BUF/pT.txt" -G"$BUF/${PA}_r.grd" | awk '{print($1,$3)}' \
    | psxy $J $RR -W"thick,$C1" -O -K >>"${OBN}-rho.eps"
    grdtrack "$BUF/pT.txt" -G"$BUF/${PA}_vp.grd" | awk '{print($1,$3)}' \
    | psxy $J $RVP -W"thick,$C1" -O -K >>"${OBN}-vp.eps"
    grdtrack "$BUF/pT.txt" -G"$BUF/${PA}_vs.grd" | awk '{print($1,$3)}' \
    | psxy $J $RVS -W"thick,$C2" -O -K >>"${OBN}-vs.eps"
}

plotit pyrolite red red
plotit bulkoc blue blue
plotit dplman black black

for PROP in r vp vs; do
    grdmath "$BUF/bulkoc_$PROP.grd" 1 MUL "$BUF/dplman_$PROP.grd" 5 MUL ADD 6 DIV = "$BUF/$PROP.grd"
done

awk '!/^#/{print($1/1e9,$2)}' "pyrolite_adiabat1600K.txt" >"$BUF/pT.txt"

grdtrack "$BUF/pT.txt" -G"$BUF/r.grd" | awk '{print($1,$3)}' \
| psxy $J $RR -W"thick,magenta" -O -K >>"${OBN}-rho.eps"
grdtrack "$BUF/pT.txt" -G"$BUF/vp.grd" | awk '{print($1,$3)}' \
| psxy $J $RVP -W"thick,magenta" -O -K >>"${OBN}-vp.eps"
grdtrack "$BUF/pT.txt" -G"$BUF/vs.grd" | awk '{print($1,$3)}' \
| psxy $J $RVS -W"thick,magenta" -O -K >>"${OBN}-vs.eps"

psbasemap $J $RR -B'a10f5:P/GPa:/a0.4f0.1:@~r@~/g cm@+-3@+:' -O -K >>"${OBN}-rho.eps"
psbasemap $J $RVP -B'a10f5:P/GPa:/a0.5f0.1:v@-p@-/km s@+-1@+:' -O >>"${OBN}-vp.eps"
psbasemap $J $RVS -B'a10f5:P/GPa:/a0.5f0.1:v@-s@-/km s@+-1@+:' -O >>"${OBN}-vs.eps"

pslegend $J $RR -Dx17/7.5/5/15/ML -O <<EOF >>"${OBN}-rho.eps"
S 0 - 0.5 - thick,red 0.5 Pyrolite
S 0 - 0.5 - thick,blue 0.5 Bulk Oceanic Crust
S 0 - 0.5 - thick,black 0.5 Depleted Mantle
S 0 - 0.5 - thick,magenta 0.5 1/6 B.O.C. + 5/6 D.M.
S 0 - 0.5 - thick,darkgreen,-- 0.5 AK135
EOF
