#!/usr/bin/env bash
set -e
APP="$(dirname "$0")"
eos="$APP/EoS/eos"

BASE="$(basename "$0" .sh)"
eval set -- $(getopt -o d:alh -l data:,all,low,high -n "$BASE" -- "$@")

RNG='all'
DAT='pyrolite'

while true; do
    case "$1" in
        -d|--data)
            DAT="$2"
            shift 2
            ;;
        -a|--all)
            RNG='all'
            shift
            ;;
        -l|--low)
            RNG='low'
            shift
            ;;
        -h|--high)
            RNG='high'
            shift
            ;;
        --)
            shift
            break
            ;;
        *)
            echo "${BASE}: Error processing arguments" >&2
            exit 1
            ;;
    esac
done

case "$RNG" in
    low)
        PTARGS=(-P=0 -toP=55e9Pa -nP=551 -ticksP=12 -T=300K -toT=3800K -nT=71 -ticksT=15)
        FILTER='(p<=55e9)&&(T<=3100)'
        P0='0'
        T0='300'
        ;;
    high)
        PTARGS=(-P=85e9Pa -toP=140e9Pa -nP=551 -ticksP=12 -T=300K -toT=3800K -nT=71 -ticksT=15)
        FILTER='(85e9<=p)&&(p<=140e9)&&(T<=3800)'
        P0='100e9'
        T0='300'
        ;;
    *)
        PTARGS=(-P=0 -toP=140e9Pa -nP=1401 -ticksP=15 -T=300K -toT=3800K -nT=71 -ticksT=15)
        FILTER='(p<=140e9)&&(T<=3800)'
        P0='0'
        T0='300'
        ;;
esac

(
    awk "!/^#/{print($P0,$T0,\$3)}" "$APP/pyrolite.txt" "$APP/bulkoc.txt" "$APP/dplman.txt" | sort -u
    awk "!/^#/{print($P0,$T0,\$3)}" "$APP/ms.txt" "$APP/fms.txt" "$APP/fmas.txt" "$APP/cfms.txt" "$APP/cfmas.txt" | sort -u
    awk "!/^#/{p=\$1;T=\$2;bits=\$3;if($FILTER){print(p,T,bits)}}" "$APP/$DAT.txt"
) \
| "$eos" bmpv "${PTARGS[@]}" -width=648 -height=686 -db=SLB11 ALL
