#I "EoS/lib/eos/"
#r "System.Xml.Linq"
#r "EoS.Core"
#r "EoS.CommandLine"

open System
open Microsoft.FSharp.Data.UnitSystems.SI.UnitSymbols
open EoS.Chemistry
open EoS.Phases
open EoS.CommandLine

let database = Flag.DatabaseOpt "db" "Phase database"
let pressure = Flag.PressureRange "P" "Pressure range"
let temperature = Flag.TemperatureRange "T" "Temperature range"

let lines fields (input:IO.TextReader) =
  let rec more () =
    match input.ReadLine() with
    | null ->
      input.Close()
      Seq.empty
    | line ->
      let line =
        let pos = line.IndexOf('#')
        (if pos >= 0 then line.[0 .. pos-1] else line).Trim()
      if String.IsNullOrEmpty(line) then
        more ()
      else
        seq { yield line.Split((null : char[]), fields, StringSplitOptions.RemoveEmptyEntries)
              yield! more () }
  more ()

let getIndex (vs : float<'U>[]) (v : float<'U>) truncate : int =
  let i = Array.BinarySearch(vs, v)
  if i >= 0 then
    i
  else
    let i = ~~~i
    if i > 0 then
      if truncate || i >= vs.Length || abs(v - vs.[i]) >= abs(v - vs.[i - 1]) then
        i - 1
      else
        i
    else
      0

let main args =
  let ps = Seq.toArray pressure.Values
  let Ts = Seq.toArray temperature.Values
  let xs = Array2D.zeroCreate ps.Length Ts.Length

  match args with
  | [|phases; xfield; xphase; element; track|] ->
    eprintfn "# Obtaing phase objects %A..." phases
    let phases = database.Value.TryGetObject<PhaseCollection>(phases).Value
    let xphase = database.Value.TryGetObject<IPhase>(xphase).Value

    let ix0, ix1 =
      phases
      |> Seq.pick (fun it ->
        if it.Phase = xphase then
          Some (it.XOffset, it.XOffset + it.Phase.XLength - 1)
        else
          None)

    eprintfn "# Reading grid from %A..." xfield
    for x in IO.File.OpenText(xfield) |> lines Int32.MaxValue do
      let x = Array.map float x
      let p = x.[0] * 1.0<Pa>
      let T = x.[1] * 1.0<K>
      let x = x.[3..]
      let ip, iT = getIndex ps p false, getIndex Ts T false
      xs.[ip, iT] <- x

    eprintfn "# Obtaining element object %A..." element
    let element = Formula.ofString element :?> Element

    eprintfn "# Reading track from %A..." track
    for x in IO.File.OpenText(track) |> lines 3 do
      let p = float x.[0] * 1.0<Pa>
      let T = float x.[1] * 1.0<K>
      let ip, iT = getIndex ps p true, getIndex Ts T true
      if xs.[ip, iT] <> null then
        let flat = xphase.Formula(xs.[ip, iT].[ix0 .. ix1]).Flatten()
        let ne =
          match flat.TryGetValue(element) with
          | true, ne -> ne
          | false, _ -> 0.0
        let no =
          match flat.TryGetValue(Element.O) with
          | true, ne -> ne
          | false, _ -> 0.0
        if ne > 0.0 || no > 0.0 then
          printfn "%g\t%g\t%g" (p/1.0e9<Pa>) (T/1.0<K>) (ne / no)

    | _ ->
      failwith "Need all phases, xfield, xphase, element and track arguments"

  0

Flag.WithCommandLineArgs main
